@@ -30,7 +30,6 @@ Structure:
 """
 __author__ = "Xiaodong Ming"
 import os
-import warnings
 import shutil
 import copy
 import scipy.signal
@@ -225,35 +224,31 @@ class InputHipims:
 
     def set_rainfall(self, rain_mask=None, rain_source=None):
         """ Set rainfall mask and rainfall source
-        rainfall_mask: numpy int array withe the same size of DEM, each mask
-                 value indicates one rainfall source
-        rainfall_source: numpy array the 1st column is time in seconds, 2nd to
+        rain_mask: numpy int array withe the same size of DEM, each mask
+                 value indicates one rainfall source 
+                 or a Raster object or a string of mask filename
+        rain_source: numpy array the 1st column is time in seconds, 2nd to
              the end columns are rainfall rates in m/s. The number of columns
              in rainfall_source should be equal to the number of mask values
              plus one (the time column)
         """
-        if rain_mask is None:
+        # set rain mask
+        if rain_mask is None: # use default or pre-defined value
             rain_mask = self.attributes['precipitation_mask']
+            rain_mask = np.array(rain_mask).astype('int32')
         elif type(rain_mask) is Raster:
-            mask_on_dem = _generate_mask_for_DEM(rain_mask, self.DEM)
-            self.attributes['precipitation_mask'] = mask_on_dem.array
-        elif type(rain_mask) is np.ndarray:
-            if rain_mask.shape == self.shape:
-                self.attributes['precipitation_mask'] = rain_mask
-            else:
+            rain_mask = _generate_mask_for_DEM(rain_mask, self.DEM)
+            self.attributes['precipitation_mask'] = rain_mask
+        else: # numpy array or scalar
+            rain_mask = np.array(rain_mask).astype('int32')
+            if rain_mask.size > 1 & rain_mask.shape != self.shape:
                 raise ValueError('The shape of rainfall_mask array '
                              'is not consistent with DEM')
-        else:
-            rain_mask = np.array(rain_mask)
-            self.attributes['precipitation_mask'] = rain_mask
-        rain_mask = rain_mask.astype('int32')
-        num_of_masks = rain_mask.max()+1 # starting from 0
-        if rain_source.shape[1]-1 != num_of_masks:
-            warning_str= ('The column of rain source '
-                          'is not consistent with the number of rain masks')
-            warnings.warn(warning_str)
-        _ = rp._check_rainfall_rate_values(rain_source, times_in_1st_col=True)
+            else:
+                self.attributes['precipitation_mask'] = rain_mask
         self.Summary.add_param_infor('precipitation_mask', rain_mask)
+        # set rain source
+        _ = rp._check_rainfall_rate_values(rain_source, times_in_1st_col=True)
         if rain_source is not None:
             self.attributes['precipitation_source'] = rain_source
             rain_mask_unique = np.unique(rain_mask).flatten()
@@ -305,7 +300,7 @@ class InputHipims:
                 obj.set_case_folder(sub_case_folder)                        
         if hasattr(self, 'Summary'):
             self.Summary.set_param('Case folder', self.case_folder)
-    
+
     def set_runtime(self, runtime=None):
         """set runtime of the model
         runtime: a list of four values representing start, end, output interval
@@ -319,7 +314,7 @@ class InputHipims:
                        '{3}-backup interval')
         runtime_str = runtime_str.format(*runtime)
         if hasattr(self, 'Summary'):
-            self.Summary.add_items('Run time', runtime_str)
+            self.Summary.add_items('Runtime(s)', runtime_str)
         return runtime_str
 
     def set_device_no(self, device_no=None):
@@ -579,19 +574,18 @@ class InputHipims:
             fig.savefig(figname, dpi=dpi)
         return fig, ax
     
-    def plot_rainfall_map(self, cellsize=None, method='sum', **kw):
-        """
+    def plot_rainfall_map(self, figname=None, method='sum', **kw):
+        """plot rainfall map within model domain
         """
         rain_source = self.attributes['precipitation_source']
         rain_mask = self.attributes['precipitation_mask']
-        if rain_mask.size == 1:
-            rain_mask = self.DEM.array*0+rain_mask
+        rain_mask = self.DEM.array*0+rain_mask
         rain_mask_obj = Raster(array=rain_mask, header=self.header)
-        rain_map_obj = rp.get_spatial_map(rain_source, rain_mask_obj, 
-                                          cellsize, method)
-        rain_map_obj.mapshow(**kw)
+        rain_map_obj = rp.get_spatial_map(rain_source, rain_mask_obj, figname,
+                                          method, **kw)
+        return rain_map_obj
 
-    def plot_rainfall_curve(self, start_date=None, method='mean'):
+    def plot_rainfall_curve(self, start_date=None, method='mean', **kw):
         """ Plot time series of average rainfall rate inside the model domain
         start_date: a datetime object to give the initial date and time of rain
         method: 'mean'|'max','min','mean'method to calculate gridded rainfall 
@@ -600,13 +594,10 @@ class InputHipims:
         rain_source = self.attributes['precipitation_source']
         rain_mask = self.attributes['precipitation_mask']
         rain_mask = np.array(rain_mask)
-        if rain_mask.size == 1:
-            rain_mask = self.DEM.array*0+rain_mask
-        else:
-            rain_mask[np.isnan(self.DEM.array)] = np.nan
+        rain_mask = self.DEM.array*0+rain_mask
         plot_data = rp.get_time_series(rain_source, rain_mask, start_date, 
                                     method=method)
-        rp.plot_time_series(plot_data, method=method)
+        rp.plot_time_series(plot_data, method=method, **kw)
         return plot_data
 
 #%%****************************************************************************
@@ -1177,6 +1168,7 @@ def _generate_mask_for_DEM(mask_origin, dem_data):
         raise ValueError('mask_origin must be either a filename ',
                          'string or a Raster object')
     mask_on_dem = dem_obj.grid_interpolate(mask_obj)
+    mask_on_dem = mask_on_dem.astype('int32')
     return mask_on_dem
 
 def copy_input_obj(obj_in):
