@@ -81,7 +81,8 @@ class ModelSummary:
         Write readme file for the summary information
         """
         if filename is None:
-            filename = self.__case_folder+'/readme.txt'
+            case_folder = self.information_dict['Case folder']
+            filename = case_folder+'/readme.txt'
         with open(filename, 'w') as file2write:
             for key, value in self.information_dict.items():
                 if '------------' in key:
