@@ -40,7 +40,7 @@ class Raster(object):
         rasterize: rasterize a shapefile on the Raster object and return a 
             bool array with 'Ture' in and on the polygon/polyline
         resample: resample the raster to a new cellsize
-        GetXYcoordinate: Get X and Y coordinates of all raster cells
+        to_points: Get X and Y coordinates of all raster cells
         mapshow: draw a map of the raster dataset
         VelocityShow: draw velocity vectors as arrows with values on two Raster
             datasets (u, v)
@@ -245,7 +245,7 @@ class Raster(object):
             Method of interpolation.
         Alias: Interpolate_to
         """
-        grid_x, grid_y = self.GetXYcoordinate()
+        grid_x, grid_y = self.to_points()
         array_interp = interpolate.griddata(points, values, (grid_x, grid_y),
                                             method=method)
         new_obj = copy.deepcopy(self)
@@ -264,11 +264,11 @@ class Raster(object):
         """
         if type(value_grid) is str:
             value_grid = Raster(value_grid)
-        points_x, points_y = value_grid.GetXYcoordinate()
+        points_x, points_y = value_grid.to_points()
         points = np.c_[points_x.flatten(), points_y.flatten()]
         values = value_grid.array.flatten()
         ind_nan = ~np.isnan(values)
-        grid_x, grid_y = self.GetXYcoordinate()
+        grid_x, grid_y = self.to_points()
         array_interp = interpolate.griddata(points[ind_nan, :], values[ind_nan],
                                             (grid_x, grid_y), method=method)
         return array_interp
@@ -313,7 +313,7 @@ class Raster(object):
         if obj_origin.header['cellsize'] != new_header['cellsize']:
             cellsize_new = new_header['cellsize']
             obj_origin = obj_origin.grid_resample_nearest(cellsize_new)
-        grid_x, grid_y = obj_origin.GetXYcoordinate()
+        grid_x, grid_y = obj_origin.to_points()
         rows, cols = sp.map2sub(grid_x, grid_y, new_header)
         ind_r = np.logical_and(rows >= 0, rows <= new_header['nrows']-1)
         ind_c = np.logical_and(cols >= 0, cols <= new_header['ncols']-1)
@@ -503,7 +503,7 @@ def merge(obj_origin, obj_target, resample_method='bilinear'):
                                    method=resample_method)
 #    else:
 #        obj_origin = self
-    grid_x, grid_y = obj_origin.GetXYcoordinate()
+    grid_x, grid_y = obj_origin.to_points()
     rows, cols = sp.map2sub(grid_x, grid_y, obj_target.header)
     ind_r = np.logical_and(rows >= 0, rows <= obj_target.header['nrows']-1)
     ind_c = np.logical_and(cols >= 0, cols <= obj_target.header['ncols']-1)
