@@ -31,7 +31,7 @@ from matplotlib.colors import LightSource
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 #%% draw inundation map with domain outline
 def mapshow(raster_obj=None, array=None, header=None, ax=None,
-            figname=None, figsize=None, dpi=300, 
+            figname=None, figsize=None, dpi=300, title=None,
             cax=True, cax_str=None, relocate=False, scale_ratio=1, **kwargs):
     """
     Display raster data without projection
@@ -69,6 +69,8 @@ def mapshow(raster_obj=None, array=None, header=None, ax=None,
         _ = _set_continous_colorbar(ax, img, cax_str)
     ax.axes.grid(linestyle='-.', linewidth=0.2)
     ax.set_aspect('equal', 'box')
+    if title is not None:
+        ax.set_title(title)
     # save figure
     if figname is not None:
         fig.savefig(figname, dpi=dpi)
